#!/bin/sh
#
# Produce list of rpm's installed after machine install date.
# Useful if reinstalling machine.
#

hostname=$(hostname -s)
filename="${hostname}_rpmlist"

target1dir="/data/prod/elin/kickstart/htdocs/autoks/postinstall/rpmlists"
target1="${target1dir}/${filename}"
target2="/local_disk/$filename"

installdate=$(date -d @$(rpm -q basesystem --qf %{InstallTime}) +%d' '%b' '%Y)

# Only run if target dir on nfs is reachable
/bin/df $target1dir &>/dev/null &
sleep 3
# Check if pid for above command is still running, if so there is a nfs problem
# and we kill the pid and terminate script. 
if /usr/bin/kill -0 $! &>/dev/null;then 
  kill -9 $!
  exit
else
  [[ -d $target1dir ]] || exit
  # List of rpm's installed after base installation
  rpmlist=$(rpm -qa --last | sed -n "/$installdate/q;p" | awk '{print$1}' | tr "\n" " ")

  if [[ -n $rpmlist ]];then
    echo | tee $target1 $target2 1>/dev/null

    # Query each rpm to get rid of version nr.
    # Also exclude rpms from different installedrpms files, except 'local'
    for rpm in $(rpm -q ${rpmlist} --qf %{name}'\n' | sort -u);do
      if ! grep $rpm $(ls /etc/smhi/installedrpms/* |grep -v local | tr "\n" " ") &>/dev/null;then
        echo $rpm | tee --append $target1 $target2 1>/dev/null
      fi
    done
  fi
fi
